@@ -13,12 +13,12 @@ import numpy as np
 import pandas as pd
 
 # tdub
-from tdub import setup_logging
+import tdub.config
 import tdub.hist
 import tdub.root
+from tdub.hist import SystematicComparison, bin_centers
 
 
-setup_logging()
 log = logging.getLogger(__name__)
 
 
@@ -44,7 +44,8 @@ def legend_last_to_first(ax: plt.Axes, **kwargs):
         Arguments passed to :py:obj:`matplotlib.axes.Axes.legend`.
 
     """
-    ax.legend()
+    if ax.get_legend() is None:
+        ax.legend()
     handles, labels = ax.get_legend_handles_labels()
     handles.insert(0, handles.pop())
     labels.insert(0, labels.pop())
@@ -60,9 +61,10 @@ def draw_atlas_label(
     lumi: float = 139,
     x: float = 0.040,
     y: float = 0.905,
-    follow_shift: float = 0.16,
+    follow_shift: float = 0.17,
     s1: int = 18,
-    s2: int = 16,
+    s2: int = 14,
+    thesis: bool = False,
 ) -> None:
     """Draw the ATLAS label text, with extra lines if desired.
 
@@ -88,19 +90,32 @@ def draw_atlas_label(
         Size of the main label.
     s2 : int
         Size of the extra text
+    thesis : bool
+        Flag for is thesis
 
     """
-    ax.text(
-        x,
-        y,
-        "ATLAS",
-        fontstyle="italic",
-        fontweight="bold",
-        transform=ax.transAxes,
-        size=s1,
-    )
-    if follow:
-        ax.text(x + follow_shift, y, follow, transform=ax.transAxes, size=s1)
+    if thesis:
+        ax.text(
+            x,
+            y,
+            "D. Davis Thesis",
+            fontstyle="italic",
+            fontweight="bold",
+            transform=ax.transAxes,
+            size=s1,
+        )
+    else:
+        ax.text(
+            x,
+            y,
+            "ATLAS",
+            fontstyle="italic",
+            fontweight="bold",
+            transform=ax.transAxes,
+            size=s1,
+        )
+        if follow:
+            ax.text(x + follow_shift, y, follow, transform=ax.transAxes, size=s1)
     if cme_and_lumi:
         exlines = [f"$\\sqrt{{s}}$ = {cme} TeV, $L = {lumi}$ fb$^{{-1}}$"]
     else:
@@ -108,7 +123,7 @@ def draw_atlas_label(
     if extra_lines is not None:
         exlines += extra_lines
     for i, exline in enumerate(exlines):
-        ax.text(x, y - (i + 1) * 0.06, exline, transform=ax.transAxes, size=s2)
+        ax.text(x, y - (i + 1) * 0.08, exline, transform=ax.transAxes, size=s2)
 
 
 def draw_uncertainty_bands(
@@ -289,6 +304,8 @@ def draw_impact_barh(
     df: pd.DataFrame,
     hi_color: str = "steelblue",
     lo_color: str = "mediumturquoise",
+    height_fill: float = 0.8,
+    height_line: float = 0.8,
 ) -> Tuple[plt.Axes, plt.Axes]:
     """Draw the impact plot.
 
@@ -302,6 +319,10 @@ def draw_impact_barh(
         Up variation color.
     lo_color : str
         Down variation color.
+    height_fill : float
+        Height for the filled bars (post-fit).
+    height_line : float
+        Height for the line (unfilled) bars (pre-fit).
 
     Returns
     -------
@@ -315,6 +336,7 @@ def draw_impact_barh(
     ax.barh(
         ys,
         df.pre_down.abs(),
+        height=height_line,
         left=df.pre_down_lefts,
         fill=False,
         edgecolor=lo_color,
@@ -324,6 +346,7 @@ def draw_impact_barh(
     ax.barh(
         ys,
         df.pre_up.abs(),
+        height=height_line,
         left=df.pre_up_lefts,
         fill=False,
         edgecolor=hi_color,
@@ -333,6 +356,7 @@ def draw_impact_barh(
     ax.barh(
         ys,
         df.post_down.abs(),
+        height=height_fill,
         left=df.post_down_lefts,
         fill=True,
         color=lo_color,
@@ -342,6 +366,7 @@ def draw_impact_barh(
     ax.barh(
         ys,
         df.post_up.abs(),
+        height=height_fill,
         left=df.post_up_lefts,
         fill=True,
         color=hi_color,
@@ -371,8 +396,87 @@ def draw_impact_barh(
     return ax, ax2
 
 
+def one_sided_comparison_plot(
+    nominal: np.ndarray,
+    one_up: np.ndarray,
+    edges: np.ndarray,
+    thesis: bool = False,
+) -> Tuple[plt.Figure, plt.Axes, plt.Axes]:
+    r"""Create plot for one sided systematic comparison.
+
+    Parameters
+    ----------
+    nominal : numpy.ndarray
+        Nominal histogram bin counts.
+    one_up : numpy.ndarray
+        One :math:`\sigma` up variation.
+    edges : numpy.ndarray
+        Array defining bin edges.
+    thesis : bool
+        Label for thesis figure.
+
+    Returns
+    -------
+    :py:obj:`matplotlib.figure.Figure`
+        Matplotlib figure.
+    :py:obj:`matplotlib.axes.Axes`
+        Matplotlib axes for the histograms.
+    :py:obj:`matplotlib.axes.Axes`
+        Matplotlib axes for the percent difference comparison.
+
+    """
+    c = SystematicComparison.one_sided(nominal, one_up)
+    centers = bin_centers(edges)
+    fig, (ax, axr) = plt.subplots(
+        2, 1, sharex=True, gridspec_kw=dict(height_ratios=[3.25, 1], hspace=0.025)
+    )
+
+    ax.hist(
+        centers,
+        bins=edges,
+        weights=c.up,
+        color="red",
+        histtype="step",
+        label=r"$+1\sigma$ Variation",
+    )
+    ax.hist(
+        centers,
+        bins=edges,
+        weights=c.down,
+        color="blue",
+        histtype="step",
+        label=r"$-1\sigma$ Variation",
+    )
+    ax.hist(
+        centers,
+        bins=edges,
+        weights=c.nominal,
+        color="black",
+        histtype="step",
+        label="Nominal",
+    )
+    ymax = c.template_max * 1.6
+    ax.set_ylim([0, ymax])
+    ax.set_ylabel("Number of Events", horizontalalignment="right", y=1.0)
+    ax.legend()
+
+    axr.hist(centers, bins=edges, weights=c.percent_diff_up, color="red", histtype="step")
+    axr.hist(
+        centers, bins=edges, weights=c.percent_diff_down, color="blue", histtype="step"
+    )
+    axr.set_ylim([c.percent_diff_min * 1.25, c.percent_diff_max * 1.25])
+    axr.set_xlim([edges[0], edges[-1]])
+    axr.plot(edges, np.zeros_like(edges), ls="-", lw=1.5, c="black")
+    axr.set_ylabel(r"$\frac{\mathrm{Sys.} - \mathrm{Nom.}}{\mathrm{Sys.}}$ [%]")
+    axr.set_xlabel("BDT Response", horizontalalignment="right", x=1.0)
+
+    fig.subplots_adjust(left=0.15)
+    draw_atlas_label(ax, follow="Simulation Internal", follow_shift=0.17, thesis=thesis)
+    return fig, ax, axr
+
+
 def setup_tdub_style() -> None:
-    """Modifies matplotlib's rcParams to our preference."""
+    """Modify matplotlib's rcParams to our preference."""
     matplotlib.rcParams["font.sans-serif"] = [
         "Helvetica",
         "helvetica",
@@ -382,24 +486,24 @@ def setup_tdub_style() -> None:
     matplotlib.rcParams["axes.formatter.limits"] = [-4, 4]
     matplotlib.rcParams["axes.formatter.use_mathtext"] = True
     matplotlib.rcParams["axes.labelsize"] = 16
-    matplotlib.rcParams["figure.figsize"] = (6.7, 6.1)
+    matplotlib.rcParams["figure.figsize"] = (6.5, 6.0)
     matplotlib.rcParams["figure.facecolor"] = "white"
     matplotlib.rcParams["figure.subplot.left"] = 0.12
     matplotlib.rcParams["figure.subplot.bottom"] = 0.1
     matplotlib.rcParams["figure.subplot.right"] = 0.965
     matplotlib.rcParams["figure.subplot.top"] = 0.95
-    matplotlib.rcParams["font.size"] = 14
+    matplotlib.rcParams["font.size"] = 12
     matplotlib.rcParams["legend.frameon"] = False
     matplotlib.rcParams["legend.numpoints"] = 1
-    matplotlib.rcParams["legend.fontsize"] = 12
+    matplotlib.rcParams["legend.fontsize"] = 13
     matplotlib.rcParams["legend.handlelength"] = 1.5
     matplotlib.rcParams["lines.linewidth"] = 1
     matplotlib.rcParams["xtick.top"] = True
     matplotlib.rcParams["ytick.right"] = True
     matplotlib.rcParams["xtick.direction"] = "in"
     matplotlib.rcParams["ytick.direction"] = "in"
-    matplotlib.rcParams["xtick.labelsize"] = 13
-    matplotlib.rcParams["ytick.labelsize"] = 13
+    matplotlib.rcParams["xtick.labelsize"] = 14
+    matplotlib.rcParams["ytick.labelsize"] = 14
     matplotlib.rcParams["xtick.minor.visible"] = True
     matplotlib.rcParams["ytick.minor.visible"] = True
     matplotlib.rcParams["xtick.major.width"] = 0.8
