@@ -26,22 +26,22 @@ class BaseTrainSummary:
 
     @property
     def features(self) -> List[str]:
-        """The list of features used."""
+        """Features used by the model."""
         return self._features
 
     @property
     def region(self) -> Region:
-        """The region where the training was executed."""
+        """Region where the training was executed."""
         return self._region
 
     @property
     def selection_used(self) -> str:
-        """The selection used on the trained datasets."""
+        """Numexpr selection used on the trained datasets."""
         return self._selection_used
 
     @property
     def summary(self) -> Dict[str, Any]:
-        """The training summary dictionary from the training json."""
+        """Training summary dictionary from the training json."""
         return self._summary
 
     def parse_summary_json(self, summary_file: os.PathLike) -> None:
@@ -90,9 +90,11 @@ class FoldedTrainSummary(BaseTrainSummary):
     --------
     >>> from tdub.apply import FoldedTrainSummary
     >>> fr_1j1b = FoldedTrainSummary("/path/to/folded_training_1j1b")
+
     """
 
     def __init__(self, fold_output: str) -> None:
+        """Class constructor."""
         fold_path = PosixPath(fold_output).resolve()
         self._model0 = joblib.load(fold_path / "model_fold0.joblib.gz")
         self._model1 = joblib.load(fold_path / "model_fold1.joblib.gz")
@@ -106,28 +108,29 @@ class FoldedTrainSummary(BaseTrainSummary):
         ----------
         summary_file : str or os.PathLike
             the summary json file
+
         """
         super().parse_summary_json(summary_file)
         self._folder = KFold(**(self.summary["kfold"]))
 
     @property
     def model0(self) -> BaseEstimator:
-        """The model for the 0th fold."""
+        """Model for the 0th fold."""
         return self._model0
 
     @property
     def model1(self) -> BaseEstimator:
-        """The model for the 1st fold."""
+        """Model for the 1st fold."""
         return self._model1
 
     @property
     def model2(self) -> BaseEstimator:
-        """The model for the 2nd fold."""
+        """Model for the 2nd fold."""
         return self._model2
 
     @property
     def folder(self) -> KFold:
-        """the folding object used during training."""
+        """Folding object used during training."""
         return self._folder
 
     def apply_to_dataframe(
@@ -150,9 +153,9 @@ class FoldedTrainSummary(BaseTrainSummary):
         column_name : str
             Name to give the BDT response variable.
         do_query : bool
-            Perform a query on the dataframe to select events belonging to
-            the region associated with ``fr`` necessary if the dataframe
-            hasn't been pre-filtered.
+            Perform a query on the dataframe to select events
+            belonging to the region associated with training result;
+            necessary if the dataframe hasn't been pre-filtered.
 
         Examples
         --------
@@ -161,6 +164,7 @@ class FoldedTrainSummary(BaseTrainSummary):
         >>> df = raw_dataframe("/path/to/file.root")
         >>> fr_1j1b = FoldedTrainSummary("/path/to/folded_training_1j1b")
         >>> fr_1j1b.apply_to_dataframe(df, do_query=True)
+
         """
         if df.shape[0] == 0:
             log.info("Dataframe is empty, doing nothing")
@@ -203,16 +207,18 @@ class SingleTrainSummary(BaseTrainSummary):
     --------
     >>> from tdub.apply import SingleTrainSummary
     >>> res_1j1b = SingleTrainSummary("/path/to/some_1j1b_training_outdir")
+
     """
 
     def __init__(self, training_output: os.PathLike) -> None:
+        """Class constructor."""
         training_path = PosixPath(training_output)
         self._model = joblib.load(training_path / "model.joblib.gz")
         self.parse_summary_json(training_path / "summary.json")
 
     @property
     def model(self) -> BaseEstimator:
-        """The trained model."""
+        """Trained model."""
         return self._model
 
     def apply_to_dataframe(
@@ -235,9 +241,9 @@ class SingleTrainSummary(BaseTrainSummary):
         column_name : str
             Name to give the BDT response variable.
         do_query : bool
-            Perform a query on the dataframe to select events belonging to
-            the region associated with ``fr`` necessary if the dataframe
-            hasn't been pre-filtered.
+            Perform a query on the dataframe to select events
+            belonging to the region associated with training result;
+            necessary if the dataframe hasn't been pre-filtered.
 
         Examples
         --------
@@ -246,8 +252,8 @@ class SingleTrainSummary(BaseTrainSummary):
         >>> df = raw_dataframe("/path/to/file.root")
         >>> sr_1j1b = SingleTrainSummary("/path/to/single_training_1j1b")
         >>> sr_1j1b.apply_to_dataframe(df, do_query=True)
-        """
 
+        """
         if df.shape[0] == 0:
             log.info("Dataframe is empty, doing nothing")
             return None
@@ -274,24 +280,24 @@ class SingleTrainSummary(BaseTrainSummary):
             df[column_name] = yhat
 
 
-def build_array(results: List[BaseTrainSummary], df: pd.DataFrame) -> np.ndarray:
-    """Get a NumPy array which is the response for all events in `df`
+def build_array(summaries: List[BaseTrainSummary], df: pd.DataFrame) -> np.ndarray:
+    """Get a NumPy array which is the response for all events in `df`.
 
-    This will use the :py:func:`~BaseTrainSummary.apply_to_dataframe` function
-    from the list of results. We query the input dataframe to ensure
-    that we apply to the correct events. If the input dataframe is
-    empty then an empty array is written to disk.
+    This will use the :py:func:`~BaseTrainSummary.apply_to_dataframe`
+    function from the list of summaries. We query the input dataframe
+    to ensure that we apply to the correct events. If the input
+    dataframe is empty then an empty array is written to disk.
 
     Parameters
     ----------
-    results : list(BaseTrainSummary)
-        Sequence of training results to use.
+    summaries : list(BaseTrainSummary)
+        Sequence of training summaries to use.
     df : pandas.DataFrame
         Dataframe of events to use to calculate the response.
 
     Examples
     --------
-    Using folded results:
+    Using folded summaries:
 
     >>> from tdub.apply import FoldedTrainSummary, build_array
     >>> from tdub.frames import raw_dataframe
@@ -301,7 +307,7 @@ def build_array(results: List[BaseTrainSummary], df: pd.DataFrame) -> np.ndarray
     >>> fr_2j2b = FoldedTrainSummary("/path/to/folded_training_2j2b")
     >>> res = build_array([fr_1j1b, fr_2j1b, fr_2j2b], df)
 
-    Using single results:
+    Using single summaries:
 
     >>> from tdub.apply import SingleTrainSummary, build_array
     >>> from tdub.frames import raw_dataframe
@@ -310,14 +316,14 @@ def build_array(results: List[BaseTrainSummary], df: pd.DataFrame) -> np.ndarray
     >>> sr_2j1b = SingleTrainSummary("/path/to/single_training_2j1b")
     >>> sr_2j2b = SingleTrainSummary("/path/to/single_training_2j2b")
     >>> res = build_array([sr_1j1b, sr_2j1b, sr_2j2b], df)
-    """
 
+    """
     if df.shape[0] == 0:
         log.info("build_array: Returning an empty array")
         return np.array([], dtype=np.float64)
 
     colname = "_temp_col"
     log.info(f"The {colname} column will be deleted at the end of this function")
-    for tr in results:
-        tr.apply_to_dataframe(df, column_name=colname, do_query=True)
+    for trsum in summaries:
+        trsum.apply_to_dataframe(df, column_name=colname, do_query=True)
     return df.pop(colname).to_numpy()
